@@ -5,14 +5,13 @@ About
 =====
 
 This package implements the game called Nim. The game can be played
-interactively in the CLI or in a web browser. You can install this package and
+interactively in the CLI, or in a web browser. You can install this package and
 play the game. Easy::
 
 > pip install nimgame
 > nimgame
 
-You can also try the game before installing the package, see the "TryIt" link
-on the left (when it will work :-))
+You can actually TryIt_, before installing anything.
 
 Those, who are more of the developer types, can use the API, after installing
 the package. The game can then be embedded in other applications and played
@@ -21,7 +20,7 @@ from any other kind of a GUI.
 For mathematicians/statisticians, it can also be used for creating statistics
 by running multiple games. If you know `combinatorial game theory`_ terms like
 `sequential game`_, `perfect information`_, `impartial game`_,
-`Sprague–Grundy theorem`_ and such, this API can be useful for you.
+`Sprague–Grundy theorem`_, this API can be useful for you.
 
 
 Game Rules
@@ -30,13 +29,12 @@ Game Rules
 For the general description of the Nim and similar games, see the
 `Wikipedia page`_.
 
-This game is played by 2 palyers (the computer can be a player).
-There are coins arranged in heaps. Some descriptions call the grouped objects
-stones, shells, matches, and the grouping may also be called piles.
-There may be any number of heaps and any number of coins in a heap.
+The game is played with coins arranged in heaps. There may be any number of
+heaps and any number of coins in a heap.
 
-Players take turns. In each turn, a player takes coins from a heap (only 1
-heap). It must be at least 1 coin. There is no upper limit (but the heap size).
+Two palyers play the game. The computer can be a player. Players take turns. In
+each turn, a player takes coins from one (only 1) heap. There is no upper limit
+of taken coins (but the heap size).  At least 1 coin must be taken.
 
 There are 2 types of the game:
 
@@ -44,14 +42,13 @@ There are 2 types of the game:
 - the "misère_" game is where the player, who has to take the last coin, loses
 
 
-Usage
-======
+API Usage
+==========
 
-After instantiating the Nim class, you need to get the heaps set up. The
-starting heaps then can be analysed and the starting player set. If it is the
-Computer, it automatically does the 1\ :sup:`st` move. Then the Player is to do
-the next move, then the Computer moves, and so on. When no more coins left, the
-game ends.
+First, the heaps are to be set up. The starting heaps then can be analysed and
+the starting player selected. If it is the Computer, it automatically does the
+1\ :sup:`st` move. Then the Player is to do the next move, then the Computer
+moves, and so on. When no more coins left, the game ends.
 
 .. code:: python
 
@@ -75,8 +72,10 @@ that class.
 
 Nim
     The main class of the game
-play_CLI
+playCLI
     A function that interactively plays the game in CLI
+playweb
+    A function that interactively plays the game in in a local web browser
 Move
     A :py:func:`collections.namedtuple` with `heapdesig` and `removecount`
     fields for defining a move, i.e. what heap is to be reduced and by how many
@@ -93,20 +92,20 @@ HeapCoinRange
     automatic heap creation.
 
 
-Package content
-===============
+Main Package content
+====================
 
 :mod:`core`
-    It provides the :class:`core.Nim` class and its public methods
+    It provides the :class:`.Nim` class and its public methods
 
 :mod:`calculations`
-    A mixin of the :class:`core.Nim` class with calculation methods
+    A mixin of the :class:`.Nim` class with calculation methods
 
 :mod:`playing.demo`
-    Functions to play the game. It can be run to do interactions for executing
+    Functions to play the game. They can be run to do interactions for executing
     automatic runs or interactive games. The same is executed when
     
-    -   the package itself is called (see the "__main__.py" module), e.g.
+    -   the package itself is called, see the "__main__.py" module, e.g.
     
         :command:`python -m nimgame`
         
@@ -120,6 +119,7 @@ Package content
     statistics.
 
 
+.. _TryIt: http://donno.yet.com
 .. _Wikipedia page: https://en.wikipedia.org/wiki/Nim
 .. _misère: https://en.wikipedia.org/wiki/Mis%C3%A8re#Mis%C3%A8re_game
 .. _combinatorial game theory: https://en.wikipedia.org/wiki/Combinatorial_game_theory
@@ -145,13 +145,13 @@ from source.core import Nim
 from source.typedefs import Move, ErrorRate, HeapCoinRange
 
 # Make the playing functions available on package level
-from source.playing.cli.play import play_CLI
+from source.playing.cli.play import playCLI
 from source.playing.web.play import playweb
 
 # For using the API in command line (e.g. Jupyter) and import all
 __all__ = (
     'Nim', 
     'Move', 'ErrorRate', 'HeapCoinRange', 
-    'play_CLI', 
+    'playCLI', 
     'playweb'
 )
