@@ -40,14 +40,26 @@ extensions = [
     'sphinx.ext.intersphinx', 
 ]
 
+# Config of extensions
 napoleon_preprocess_types = True
-
 autosummary_generate = False
-
 intersphinx_mapping = {
-    'python': ('https://docs.python.org/3.5', None)
+    'python': ('https://docs.python.org/3.7', None)
 }
 
+# Packages not to be imported and considered by Sphinx
+autodoc_mock_imports = ["js"]
+
+# Make clases and types available as aliases
+autodoc_type_aliases = dict( 
+    Nim='Nim', 
+    Move='Move', 
+    ErrorRate_T='typedefs.ErrorRate_T', 
+    HeapCoinRange_T='typedefs.HeapCoinRange_T', 
+    MyTurn_T='typedefs.MyTurn_T', 
+)
+autodoc_typehints_format = 'short'
+
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
 
