@@ -1,10 +1,11 @@
 """The Nim Game calculation functions
 
 This module defines the functions that are needed to calculate moves and
-decisions in a :class:`Mixin` for the :class:`core.Nim` class.
+decisions in a :class:`Mixin` for the :class:`.Nim` class.
 """
 
 
+from __future__ import annotations
 import functools
 import random
 from source.typedefs import Move, ErrorRate
@@ -13,7 +14,7 @@ from source.typedefs import Move, ErrorRate
 class Mixin:
     """Class to implement the Nim game calculations
     
-    This Mixin is used as an ancestor class for :class:`core.Nim`, so
+    This Mixin is used as an ancestor class for :class:`.Nim`, so
     that we can define methods here, in a separate module.
     
     The term "nimsum" (Grundy value or nim-value), used here, is the Nimber_
