@@ -4,7 +4,7 @@ This main class implements the init and maintenance of heaps, movements of
 coins, records the statuses and calculates decisions.
 """
 
-
+from __future__ import annotations
 from dataclasses import dataclass
 import itertools
 import random; random.seed()
@@ -19,7 +19,7 @@ class Nim(calculations.Mixin):
     """The main class to implement the Nim game
     
     This class publishes the following methods. See also the calculation methods
-    from the mixin in :mod:`source.calculations`.
+    from the mixin in :mod:`calculations`.
 
     **Instance Methods:**
     
