@@ -23,12 +23,12 @@ if packagepath not in sys.path:
 # Simulate "import nimgame" (as the package may not be installed yet)
 from source.core import Nim as _Nim
 from source.typedefs import ErrorRate as _ErrorRate
-from source.playing.cli.play import play_CLI as _play_CLI
+from source.playing.cli.play import playCLI as _playCLI
 from source.playing.web.play import playweb as _playweb
 nimgame = types.SimpleNamespace()
 nimgame.Nim = _Nim
 nimgame.ErrorRate = _ErrorRate
-nimgame.play_CLI = _play_CLI
+nimgame.playCLI = _playCLI
 nimgame.playweb = _playweb
 
 from source.playing.cli import ansi
